"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConsumptionUnitCode = exports.getConsumptionUnit = void 0;
const interfaces_1 = require("@sage/wh-master-data/lib/interfaces");
const xtrem_client_1 = require("@sage/xtrem-client");
const ui = require("@sage/xtrem-ui");
/**
 *  Read the product consumption unit
 *  @param pageInstance
 *  @param siteCode
 *  @param depositorCode
 *  @param productCode
 *  @returns
 */
async function getConsumptionUnit(pageInstance, siteCode, depositorCode, productCode) {
    if (siteCode && productCode && depositorCode) {
        try {
            return ((0, xtrem_client_1.extractEdges)(await pageInstance.$.graph
                .node('@sage/wh-product-data/ProductsContainer')
                .query(ui.queryUtils.edgesSelector({
                numberOfConsumptionUnit: true,
                container: {
                    code: true,
                },
            }, {
                filter: {
                    _and: [
                        {
                            site: {
                                code: siteCode,
                            },
                        },
                        {
                            depositor: {
                                code: depositorCode,
                            },
                        },
                        { product: { code: productCode } },
                        { isActive: true },
                        { containerLevel: interfaces_1.hightestContainerLevel },
                    ],
                },
                first: 10,
                orderBy: { containerLevel: -1, container: { code: 1 } },
            }))
                .execute())?.map(_ => ({
                code: _.container?.code,
                numberOfConsumptionUnit: Number(_.numberOfConsumptionUnit),
            }))?.[0] ?? null);
        }
        catch (error) {
            ui.console.error('Error reading product container:\n', JSON.stringify(error));
            return null;
        }
    }
    return null;
}
exports.getConsumptionUnit = getConsumptionUnit;
/**
 *  Read the product consumption unit Code
 *  @param pageInstance
 *  @param siteCode
 *  @param depositorCode
 *  @param productCode
 *  @returns
 */
async function getConsumptionUnitCode(pageInstance, siteCode, depositorCode, productCode) {
    return (await getConsumptionUnit(pageInstance, siteCode, depositorCode, productCode))?.code ?? null;
}
exports.getConsumptionUnitCode = getConsumptionUnitCode;
//# sourceMappingURL=getConsumptionUnit.js.map