"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setDocumentDestination = exports.setLabelDestination = exports.getDocumentDestination = exports.getLabelDestination = exports.removeLabelDocumentDestination = exports.setLabelDocumentDestinationCode = exports.setLabelDocumentDestination = exports.getLabelDocumentDestination = exports.saveSelectedSiteDepositor = exports.setSelectedDepositor = exports.setSelectedSite = exports.removeSelectedSiteDepositor = exports.setSelectedSiteDepositor = exports.setSelectedSiteDepositorByCode = exports.getSelectedDepositor = exports.getSelectedSite = exports.getSelectedSiteDepositor = void 0;
const xtrem_decimal_1 = require("@sage/xtrem-decimal"), typesLib = xtrem_decimal_1;
const ui = require("@sage/xtrem-ui");
/**
 *  Get the selected site and depositor
 * @param pageInstance
 * @returns
 */
function getSelectedSiteDepositor(pageInstance) {
    const siteDepositor = pageInstance.$.storage.get('mobile-selected-site-depositor');
    return siteDepositor ? JSON.parse(siteDepositor) : undefined;
}
exports.getSelectedSiteDepositor = getSelectedSiteDepositor;
/**
 *  Get the selected site
 * @param pageInstance
 * @returns
 */
function getSelectedSite(pageInstance) {
    return getSelectedSiteDepositor(pageInstance)?.site;
}
exports.getSelectedSite = getSelectedSite;
/**
 *  Get the selected depositor
 * @param pageInstance
 * @returns
 */
function getSelectedDepositor(pageInstance) {
    return getSelectedSiteDepositor(pageInstance)?.depositor;
}
exports.getSelectedDepositor = getSelectedDepositor;
/**
 * Set the selected site and depositor
 * @param pageInstance
 * @param site
 * @param depositor
 */
function setSelectedSiteDepositorByCode(pageInstance, site, depositor) {
    if (site) {
        setSelectedSiteDepositor(pageInstance, {
            site: site,
            ...(depositor && { depositor: depositor }),
        });
    }
    else {
        removeSelectedSiteDepositor(pageInstance);
    }
}
exports.setSelectedSiteDepositorByCode = setSelectedSiteDepositorByCode;
/**
 * Set the selected site and depositor
 * @param pageInstance
 * @param siteDepositor
 */
function setSelectedSiteDepositor(pageInstance, siteDepositor) {
    if (siteDepositor) {
        pageInstance.$.storage.set('mobile-selected-site-depositor', JSON.stringify(siteDepositor));
    }
    else {
        removeSelectedSiteDepositor(pageInstance);
    }
}
exports.setSelectedSiteDepositor = setSelectedSiteDepositor;
/**
 * Remove the selected site and depositor
 * @param pageInstance
 */
function removeSelectedSiteDepositor(pageInstance) {
    pageInstance.$.storage.remove('mobile-selected-site-depositor');
}
exports.removeSelectedSiteDepositor = removeSelectedSiteDepositor;
/**
 * Set the selected site
 * @param pageInstance
 * @param site
 */
function setSelectedSite(pageInstance, site) {
    setSelectedSiteDepositor(pageInstance, site ? { site: site } : undefined);
}
exports.setSelectedSite = setSelectedSite;
/**
 * Set the selected depositor
 * @param pageInstance
 * @param depositor
 */
function setSelectedDepositor(pageInstance, depositor) {
    setSelectedSiteDepositor(pageInstance, {
        site: getSelectedSite(pageInstance),
        ...(depositor && { depositor: depositor }),
    });
}
exports.setSelectedDepositor = setSelectedDepositor;
/**
 * Save the selected site and depositor to X3
 * @param pageInstance
 * @param siteDepositor
 * @returns
 */
async function saveSelectedSiteDepositor(pageInstance, user, siteDepositor) {
    if (siteDepositor?.site && siteDepositor?.depositor) {
        const _args = {
            user: user ?? '',
            site: siteDepositor.site,
            depositor: siteDepositor.depositor,
            errorCode: -1,
        };
        try {
            const response = (await pageInstance.$.graph
                .node('@sage/wh-system/UserParameterValue')
                .mutations.updateUserSiteDepositor({
                errorCode: true,
            }, { parameters: _args })
                .execute());
            // Check if the response is valid (API error)
            if (typesLib.strictEq(response?.errorCode, undefined) || typesLib.eq(response?.errorCode, -1)) {
                return false;
            }
            // Check if error occurred)
            return !response.errorCode;
        }
        catch (error) {
            ui.console.error('Error saving selected site and depositor', error?.message);
        }
    }
    return false;
}
exports.saveSelectedSiteDepositor = saveSelectedSiteDepositor;
/**
 * Get the label and document destinations
 * @param pageInstance
 * @returns
 */
function getLabelDocumentDestination(pageInstance) {
    const labelDocumentDestination = pageInstance.$.storage.get('mobile-label-document-destination');
    return labelDocumentDestination ? JSON.parse(labelDocumentDestination) : undefined;
}
exports.getLabelDocumentDestination = getLabelDocumentDestination;
/**
 * Set the label and document destinations
 * @param pageInstance
 * @param labelDocumentDestination
 */
function setLabelDocumentDestination(pageInstance, labelDocumentDestination) {
    if (labelDocumentDestination &&
        (labelDocumentDestination.labelDestination || labelDocumentDestination.documentDestination)) {
        pageInstance.$.storage.set('mobile-label-document-destination', JSON.stringify({
            ...(labelDocumentDestination.labelDestination && {
                labelDestination: labelDocumentDestination.labelDestination,
            }),
            ...(labelDocumentDestination.documentDestination && {
                documentDestination: labelDocumentDestination.documentDestination,
            }),
        }));
    }
    else {
        removeLabelDocumentDestination(pageInstance);
    }
}
exports.setLabelDocumentDestination = setLabelDocumentDestination;
/**
 * Set the label and document destinations by codes
 * @param pageInstance
 * @returns
 */
function setLabelDocumentDestinationCode(pageInstance, labelDestination, documentDestination) {
    if (labelDestination || documentDestination) {
        setLabelDocumentDestination(pageInstance, {
            ...(labelDestination && { labelDestination: labelDestination }),
            ...(documentDestination && { documentDestination: documentDestination }),
        });
    }
    else {
        removeLabelDocumentDestination(pageInstance);
    }
}
exports.setLabelDocumentDestinationCode = setLabelDocumentDestinationCode;
/**
 * Remove the label and document destinations
 * @param pageInstance
 */
function removeLabelDocumentDestination(pageInstance) {
    pageInstance.$.storage.remove('mobile-label-document-destination');
}
exports.removeLabelDocumentDestination = removeLabelDocumentDestination;
/**
 * Get the label destination
 * @param pageInstance
 * @returns
 */
function getLabelDestination(pageInstance) {
    return getLabelDocumentDestination(pageInstance)?.labelDestination;
}
exports.getLabelDestination = getLabelDestination;
/**
 * Get the document destination
 * @param pageInstance
 * @returns
 */
function getDocumentDestination(pageInstance) {
    return getLabelDocumentDestination(pageInstance)?.documentDestination;
}
exports.getDocumentDestination = getDocumentDestination;
/**
 * Set the label destination
 * @param pageInstance
 * @param labelDestination
 */
function setLabelDestination(pageInstance, labelDestination) {
    setLabelDocumentDestination(pageInstance, {
        labelDestination: labelDestination,
        documentDestination: getLabelDocumentDestination(pageInstance)?.documentDestination,
    });
}
exports.setLabelDestination = setLabelDestination;
/**
 * Set the document destination
 * @param pageInstance
 * @param documentDestination
 */
function setDocumentDestination(pageInstance, documentDestination) {
    setLabelDocumentDestination(pageInstance, {
        labelDestination: getLabelDocumentDestination(pageInstance)?.labelDestination,
        documentDestination: documentDestination,
    });
}
exports.setDocumentDestination = setDocumentDestination;
//# sourceMappingURL=storage-properties.js.map