import { hightestContainerLevel } from '@sage/wh-master-data/lib/interfaces';
import { ProductsContainer } from '@sage/wh-product-data-api';
import { extractEdges } from '@sage/xtrem-client';
import * as ui from '@sage/xtrem-ui';
import { ConsumptionUnit } from '../interfaces';

/**
 *  Read the product consumption unit
 *  @param pageInstance
 *  @param siteCode
 *  @param depositorCode
 *  @param productCode
 *  @returns
 */
export async function getConsumptionUnit(
    pageInstance: any,
    siteCode: string,
    depositorCode: string,
    productCode: string,
): Promise<ConsumptionUnit | null> {
    if (siteCode && productCode && depositorCode) {
        interface ResultProductsContainer {
            numberOfConsumptionUnit: string;
            container: {
                code?: string;
            };
        }
        try {
            return (
                extractEdges<ResultProductsContainer>(
                    await pageInstance.$.graph
                        .node('@sage/wh-product-data/ProductsContainer')
                        .query(
                            ui.queryUtils.edgesSelector<ProductsContainer>(
                                {
                                    numberOfConsumptionUnit: true,
                                    container: {
                                        code: true,
                                    },
                                },
                                {
                                    filter: {
                                        _and: [
                                            {
                                                site: {
                                                    code: siteCode,
                                                },
                                            },
                                            {
                                                depositor: {
                                                    code: depositorCode,
                                                },
                                            },
                                            { product: { code: productCode } },
                                            { isActive: true },
                                            { containerLevel: hightestContainerLevel },
                                        ],
                                    },
                                    first: 10,
                                    orderBy: { containerLevel: -1, container: { code: 1 } },
                                },
                            ),
                        )
                        .execute(),
                )?.map<ConsumptionUnit>(
                    _ =>
                        <ConsumptionUnit>{
                            code: _.container?.code,
                            numberOfConsumptionUnit: Number(_.numberOfConsumptionUnit),
                        },
                )?.[0] ?? null
            );
        } catch (error) {
            ui.console.error('Error reading product container:\n', JSON.stringify(error));
            return null;
        }
    }
    return null;
}

/**
 *  Read the product consumption unit Code
 *  @param pageInstance
 *  @param siteCode
 *  @param depositorCode
 *  @param productCode
 *  @returns
 */
export async function getConsumptionUnitCode(
    pageInstance: any,
    siteCode: string,
    depositorCode: string,
    productCode: string,
): Promise<string | null> {
    return (await getConsumptionUnit(pageInstance, siteCode, depositorCode, productCode))?.code ?? null;
}
